% Auto-generated chapter 92 for bukhari
% Hadiths in this chapter: 83

\hadithdefcmd{bukhari}{7048}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَتْ أَسْمَاءُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَنَا عَلَى، حَوْضِي أَنْتَظِرُ مَنْ يَرِدُ عَلَىَّ، فَيُؤْخَذُ بِنَاسٍ مِنْ دُونِي فَأَقُولُ أُمَّتِي‏.‏ فَيَقُولُ لاَ تَدْرِي، مَشَوْا عَلَى الْقَهْقَرَى ‏"‏‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ أَنْ نَرْجِعَ عَلَى أَعْقَابِنَا أَوْ نُفْتَنَ‏.‏\hadithno{7048}\hadithtrans{Narrated Asma':The Prophet (ﷺ) said, "I will be at my Lake-Fount (Kauthar) waiting for whoever will come to me. Then some people will be taken away from me whereupon I will say, 'My followers!' It will be said, 'You do not know they turned Apostates as renegades (deserted their religion).'" (Ibn Abi Mulaika said, "Allah, we seek refuge with You from turning on our heels from the (Islamic) religion and from being put to trial}}
\hadithdefcmd{bukhari}{7049}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَنَا فَرَطُكُمْ عَلَى الْحَوْضِ، لَيُرْفَعَنَّ إِلَىَّ رِجَالٌ مِنْكُمْ حَتَّى إِذَا أَهْوَيْتُ لأُنَاوِلَهُمُ اخْتُلِجُوا دُونِي فَأَقُولُ أَىْ رَبِّ أَصْحَابِي‏.‏ يَقُولُ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏‏.‏\hadithno{7049}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "I am your predecessor at the Lake-Fount (Kauthar) and some men amongst you will be brought to me, and when I will try to hand them some water, they will be pulled away from me by force whereupon I will say, 'O Lord, my companions!' Then the Almighty will say, 'You do not know what they did after you left, they introduced new things into the religion after you}}
\hadithdefcmd{bukhari}{7050}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ، مَنْ وَرَدَهُ شَرِبَ مِنْهُ، وَمَنْ شَرِبَ مِنْهُ لَمْ يَظْمَأْ بَعْدَهُ أَبَدًا، لَيَرِدُ عَلَىَّ أَقْوَامٌ أَعْرِفُهُمْ وَيَعْرِفُونِي، ثُمَّ يُحَالُ بَيْنِي وَبَيْنَهُمْ ‏"‏‏.‏\hadithno{7050}\hadithtrans{Narrated Sahl bin Sa`d:I heard the Prophet (ﷺ) saying, "I am your predecessor at the Lake-Fount (Kauthar), and whoever will come to it, will drink from it, and whoever will drink from it, will never become thirsty after that. There will come to me some people whom I know and they know me, and then a barrier will be set up between me and them}}
\hadithdefcmd{bukhari}{7051}{قَالَ أَبُو حَازِمٍ فَسَمِعَنِي النُّعْمَانُ بْنُ أَبِي عَيَّاشٍ، وَأَنَا أُحَدِّثُهُمْ، هَذَا فَقَالَ هَكَذَا سَمِعْتَ سَهْلاً، فَقُلْتُ نَعَمْ‏.‏ قَالَ وَأَنَا أَشْهَدُ، عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ لَسَمِعْتُهُ يَزِيدُ فِيهِ قَالَ ‏ "‏ إِنَّهُمْ مِنِّي‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا بَدَّلُوا بَعْدَكَ فَأَقُولُ سُحْقًا سُحْقًا لِمَنْ بَدَّلَ بَعْدِي ‏"‏‏.‏\hadithno{7051}\hadithtrans{Abu Sa`id Al-Khudri added that the Prophet (ﷺ) further said:"I will say those people are from me. It will be said, 'You do not know what changes and new things they did after you.' Then I will say, 'Far removed (from mercy), far removed (from mercy), those who changed (the religion) after me}}
\hadithdefcmd{bukhari}{7052}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، سَمِعْتُ عَبْدَ اللَّهِ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُمْ سَتَرَوْنَ بَعْدِي أَثَرَةً وَأُمُورًا تُنْكِرُونَهَا‏"‏‏.‏ قَالُوا فَمَا تَأْمُرُنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَدُّوا إِلَيْهِمْ حَقَّهُمْ وَسَلُوا اللَّهَ حَقَّكُمْ ‏"‏‏.‏\hadithno{7052}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said to us, "You will see after me, selfishness (on the part of other people) and other matters that you will disapprove of." They asked, "What do you order us to do, O Allah's Messenger (ﷺ)? (under such circumstances)?" He said, "Pay their rights to them (to the rulers) and ask your right from Allah}}
\hadithdefcmd{bukhari}{7053}{حَدَّثَنَا مُسَدَّدٌ، عَنْ عَبْدِ الْوَارِثِ، عَنِ الْجَعْدِ، عَنْ أَبِي رَجَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَرِهَ مِنْ أَمِيرِهِ شَيْئًا فَلْيَصْبِرْ، فَإِنَّهُ مَنْ خَرَجَ مِنَ السُّلْطَانِ شِبْرًا مَاتَ مِيتَةً جَاهِلِيَّةً ‏"‏‏.‏\hadithno{7053}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Whoever disapproves of something done by his ruler then he should be patient, for whoever disobeys the ruler even a little (little = a span) will die as those who died in the Pre-Islamic Period of Ignorance. (i.e. as rebellious Sinners)}}
\hadithdefcmd{bukhari}{7054}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الْجَعْدِ أَبِي عُثْمَانَ، حَدَّثَنِي أَبُو رَجَاءٍ الْعُطَارِدِيُّ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَأَى مِنْ أَمِيرِهِ شَيْئًا يَكْرَهُهُ فَلْيَصْبِرْ عَلَيْهِ، فَإِنَّهُ مَنْ فَارَقَ الْجَمَاعَةَ شِبْرًا فَمَاتَ، إِلاَّ مَاتَ مِيتَةً جَاهِلِيَّةً ‏"‏‏.‏\hadithno{7054}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Whoever notices something which he dislikes done by his ruler, then he should be patient, for whoever becomes separate from the company of the Muslims even for a span and then dies, he will die as those who died in the Pre-Islamic period of Ignorance (as rebellious sinners). (Fath-ul-Bari page 112, Vol)}}
\hadithdefcmd{bukhari}{7056}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ عَمْرٍو، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، قَالَ دَخَلْنَا عَلَى عُبَادَةَ بْنِ الصَّامِتِ وَهْوَ مَرِيضٌ قُلْنَا أَصْلَحَكَ اللَّهُ حَدِّثْ بِحَدِيثٍ، يَنْفَعُكَ اللَّهُ بِهِ سَمِعْتَهُ مِنَ النَّبِيِّ، صلى الله عليه وسلم‏.‏ قَالَ دَعَانَا النَّبِيُّ صلى الله عليه وسلم فَبَايَعْنَاهُ فَقَالَ فِيمَا أَخَذَ عَلَيْنَا أَنْ بَايَعَنَا عَلَى السَّمْعِ وَالطَّاعَةِ، فِي مَنْشَطِنَا وَمَكْرَهِنَا، وَعُسْرِنَا، وَيُسْرِنَا، وَأَثَرَةٍ عَلَيْنَا، وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ، إِلاَّ أَنْ تَرَوْا كُفْرًا بَوَاحًا، عِنْدَكُمْ مِنَ اللَّهِ فِيهِ بُرْهَانٌ‏.‏\hadithno{7056}\hadithtrans{Narrated Junada bin Abi Umaiya:We entered upon 'Ubada bin As-Samit while he was sick. We said, "May Allah make you healthy. Will you tell us a Hadith you heard from the Prophet (ﷺ) and by which Allah may make you benefit?" He said, "The Prophet (ﷺ) called us and we gave him the Pledge of allegiance for Islam, and among the conditions on which he took the Pledge from us, was that we were to listen and obey (the orders) both at the time when we were active and at the time when we were tired, and at our difficult time and at our ease and to be obedient to the ruler and give him his right even if he did not give us our right, and not to fight against him unless we noticed him having open Kufr (disbelief) for which we would have a proof with us from Allah}}
\hadithdefcmd{bukhari}{7057}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ اسْتَعْمَلْتَ فُلاَنًا وَلَمْ تَسْتَعْمِلْنِي‏.‏ قَالَ ‏ "‏ إِنَّكُمْ سَتَرَوْنَ بَعْدِي أَثَرَةً، فَاصْبِرُوا حَتَّى تَلْقَوْنِي ‏"‏‏.‏\hadithno{7057}\hadithtrans{Narrated Usaid bin Hudair:A man came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! You appointed such-and-such person and you did not appoint me?" The Prophet (ﷺ) said, "After me you will see rulers not giving you your right (but you should give them their right) and be patient till you meet me}}
\hadithdefcmd{bukhari}{7058}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي جَدِّي، قَالَ كُنْتُ جَالِسًا مَعَ أَبِي هُرَيْرَةَ فِي مَسْجِدِ النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ وَمَعَنَا مَرْوَانُ قَالَ أَبُو هُرَيْرَةَ سَمِعْتُ الصَّادِقَ الْمَصْدُوقَ يَقُولُ ‏ "‏ هَلَكَةُ أُمَّتِي عَلَى يَدَىْ غِلْمَةٍ مِنْ قُرَيْشٍ ‏"‏‏.‏ فَقَالَ مَرْوَانُ لَعْنَةُ اللَّهِ عَلَيْهِمْ غِلْمَةً‏.‏ فَقَالَ أَبُو هُرَيْرَةَ لَوْ شِئْتُ أَنْ أَقُولَ بَنِي فُلاَنٍ وَبَنِي فُلاَنٍ لَفَعَلْتُ‏.‏ فَكُنْتُ أَخْرُجُ مَعَ جَدِّي إِلَى بَنِي مَرْوَانَ حِينَ مَلَكُوا بِالشَّأْمِ، فَإِذَا رَآهُمْ غِلْمَانًا أَحْدَاثًا قَالَ لَنَا عَسَى هَؤُلاَءِ أَنْ يَكُونُوا مِنْهُمْ قُلْنَا أَنْتَ أَعْلَمُ‏.‏\hadithno{7058}\hadithtrans{Narrated Abu Huraira:I heard the truthful and trusted by Allah (i.e., the Prophet (ﷺ) ) saying, "The destruction of my followers will be through the hands of young men from Quraish}}
\hadithdefcmd{bukhari}{7059}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، أَنَّهُ سَمِعَ الزُّهْرِيَّ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ حَبِيبَةَ، عَنْ زَيْنَبَ ابْنَةِ جَحْشٍ ـ رضى الله عنهن ـ أَنَّهَا قَالَتِ اسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم مِنَ النَّوْمِ مُحْمَرًّا وَجْهُهُ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ، فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَاجُوجَ وَمَاجُوجَ مِثْلُ هَذِهِ ‏"‏‏.‏ وَعَقَدَ سُفْيَانُ تِسْعِينَ أَوْ مِائَةً‏.‏ قِيلَ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ، إِذَا كَثُرَ الْخَبَثُ ‏"‏‏.‏\hadithno{7059}\hadithtrans{Narrated Zainab bint Jahsh:The Prophet (ﷺ) got up from his sleep with a flushed red face and said, "None has the right to be worshipped but Allah. Woe to the Arabs, from the Great evil that is nearly approaching them. Today a gap has been made in the wall of Gog and Magog like this." (Sufyan illustrated by this forming the number 90 or 100 with his fingers.) It was asked, "Shall we be destroyed though there are righteous people among us?" The Prophet (ﷺ) said, "Yes, if evil increased}}
\hadithdefcmd{bukhari}{7060}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ،‏.‏ وَحَدَّثَنِي مَحْمُودٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ بْنِ زَيْد ٍ ـ رضى الله عنهما ـ قَالَ أَشْرَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُطُمٍ مِنْ آطَامِ الْمَدِينَةِ فَقَالَ ‏"‏ هَلْ تَرَوْنَ مَا أَرَى ‏"‏‏.‏ قَالُوا لاَ‏.‏ قَالَ ‏"‏ فَإِنِّي لأَرَى الْفِتَنَ تَقَعُ خِلاَلَ بُيُوتِكُمْ كَوَقْعِ الْقَطْرِ ‏"‏‏.‏\hadithno{7060}\hadithtrans{Narrated Usama bin Zaid:Once the Prophet (ﷺ) stood over one of the high buildings of Medina and then said (to the people), "Do you see what I see?" They said, "No." He said, "I see afflictions falling among your houses as rain drops fall}}
\hadithdefcmd{bukhari}{7061}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، أَخْبَرَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَتَقَارَبُ الزَّمَانُ، وَيَنْقُصُ الْعَمَلُ، وَيُلْقَى الشُّحُّ، وَتَظْهَرُ الْفِتَنُ، وَيَكْثُرُ الْهَرْجُ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَيُّمَ هُوَ‏.‏ قَالَ ‏"‏ الْقَتْلُ الْقَتْلُ ‏"‏‏.‏ وَقَالَ شُعَيْبٌ وَيُونُسُ وَاللَّيْثُ وَابْنُ أَخِي الزُّهْرِيِّ عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7061}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Time will pass rapidly, good deeds will decrease, miserliness will be thrown (in the hearts of the people) afflictions will appear and there will be much 'Al-Harj." They said, "O Allah's Apostle! What is "Al-Harj?" He said, "Killing! Killing!" (See Hadith No. 63, Vol)}}
\hadithdefcmd{bukhari}{7063}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالاَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ لأَيَّامًا يَنْزِلُ فِيهَا الْجَهْلُ، وَيُرْفَعُ فِيهَا الْعِلْمُ، وَيَكْثُرُ فِيهَا الْهَرْجُ، وَالْهَرْجُ الْقَتْلُ ‏"‏‏.‏\hadithno{7063}\hadithtrans{Narrated `Abdullah and Abu Musa:The Prophet (ﷺ) said, "Near the establishment of the Hour there will be days during which Religious ignorance will spread, knowledge will be taken away (vanish) and there will be much Al-Harj, and Al- Harj means killing}}
\hadithdefcmd{bukhari}{7064}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، قَالَ جَلَسَ عَبْدُ اللَّهِ وَأَبُو مُوسَى فَتَحَدَّثَا فَقَالَ أَبُو مُوسَى قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ أَيَّامًا يُرْفَعُ فِيهَا الْعِلْمُ، وَيَنْزِلُ فِيهَا الْجَهْلُ، وَيَكْثُرُ فِيهَا الْهَرْجُ، وَالْهَرْجُ الْقَتْلُ ‏"‏‏.‏\hadithno{7064}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Near the establishment of the Hour there will be days during which (religious) knowledge will be taken away (vanish) and general ignorance will spread, and there will be Al-Harj in abundance, and Al-Harj means killing}}
\hadithdefcmd{bukhari}{7065}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ إِنِّي لَجَالِسٌ مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى ـ رضى الله عنهما ـ فَقَالَ أَبُو مُوسَى سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم مِثْلَهُ، وَالْهَرْجُ بِلِسَانِ الْحَبَشَةِ الْقَتْلُ‏.‏\hadithno{7065}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said...(as above, 185). And Harj, in the Ethiopian language, means killing}}
\hadithdefcmd{bukhari}{7066}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، وَأَحْسِبُهُ، رَفَعَهُ قَالَ ‏ "‏ بَيْنَ يَدَىِ السَّاعَةِ أَيَّامُ الْهَرْجِ، يَزُولُ الْعِلْمُ، وَيَظْهَرُ فِيهَا الْجَهْلُ ‏"‏‏.‏ قَالَ أَبُو مُوسَى وَالْهَرْجُ الْقَتْلُ بِلِسَانِ الْحَبَشَةِ‏.‏\hadithno{7066}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Near the establishment of the Hour, there will be the days of Al-Harj, and the religious knowledge will be taken away (vanish i.e. by the death of Religious scholars) and general ignorance will spread." Abu Musa said, "Al-Harj, in the Ethiopian language, means killing}}
\hadithdefcmd{bukhari}{7067}{وَقَالَ أَبُو عَوَانَةَ عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنِ الأَشْعَرِيِّ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ تَعْلَمُ الأَيَّامَ الَّتِي ذَكَرَ النَّبِيُّ صلى الله عليه وسلم أَيَّامَ الْهَرْجِ‏.‏ نَحْوَهُ‏.‏ قَالَ ابْنُ مَسْعُودٍ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مِنْ شِرَارِ النَّاسِ مَنْ تُدْرِكُهُمُ السَّاعَةُ وَهُمْ أَحْيَاءٌ ‏"‏‏.‏\hadithno{7067}\hadithtrans{Ibn Mas`ud added: I heard Allah's Messenger (ﷺ) saying; (It will be) from among the most wicked people who will be living at the time when the Hour will be established}}
\hadithdefcmd{bukhari}{7068}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، قَالَ أَتَيْنَا أَنَسَ بْنَ مَالِكٍ فَشَكَوْنَا إِلَيْهِ مَا نَلْقَى مِنَ الْحَجَّاجِ فَقَالَ ‏ "‏ اصْبِرُوا، فَإِنَّهُ لاَ يَأْتِي عَلَيْكُمْ زَمَانٌ إِلاَّ الَّذِي بَعْدَهُ شَرٌّ مِنْهُ، حَتَّى تَلْقَوْا رَبَّكُمْ ‏"‏‏.‏ سَمِعْتُهُ مِنْ نَبِيِّكُمْ صلى الله عليه وسلم‏.‏\hadithno{7068}\hadithtrans{Narrated Az-Zubair bin `Adi:We went to Anas bin Malik and complained about the wrong we were suffering at the hand of Al- Hajjaj. Anas bin Malik said, "Be patient till you meet your Lord, for no time will come upon you but the time following it will be worse than it. I heard that from the Prophet}}
\hadithdefcmd{bukhari}{7069}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ الْفِرَاسِيَّةِ، أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتِ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً فَزِعًا يَقُولُ ‏ "‏ سُبْحَانَ اللَّهِ مَاذَا أَنْزَلَ اللَّهُ مِنَ الْخَزَائِنِ وَمَاذَا أُنْزِلَ مِنَ الْفِتَنِ، مَنْ يُوقِظُ صَوَاحِبَ الْحُجُرَاتِ ـ يُرِيدُ أَزْوَاجَهُ ـ لِكَىْ يُصَلِّينَ، رُبَّ كَاسِيَةٍ فِي الدُّنْيَا، عَارِيَةٍ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{7069}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) Allah's Messenger (ﷺ) woke up one night in a state of terror and said, "Subhan Allah, How many treasures Allah has sent down! And how many afflictions have been sent down! Who will go and wake the lady dwellers (wives of the Prophet) up of these rooms (for prayers)?" He meant his wives, so that they might pray. He added, "A well-dressed (soul) in this world may be naked in the Hereafter}}
\hadithdefcmd{bukhari}{7070}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏‏.‏\hadithno{7070}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Whoever takes up arms against us, is not from us}}
\hadithdefcmd{bukhari}{7071}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏‏.‏\hadithno{7071}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Whoever takes up arms against us, is not from us}}
\hadithdefcmd{bukhari}{7072}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُشِيرُ أَحَدُكُمْ عَلَى أَخِيهِ بِالسِّلاَحِ، فَإِنَّهُ لاَ يَدْرِي لَعَلَّ الشَّيْطَانَ يَنْزِعُ فِي يَدِهِ، فَيَقَعُ فِي حُفْرَةٍ مِنَ النَّارِ ‏"‏‏.‏\hadithno{7072}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None of you should point out towards his Muslim brother with a weapon, for he does not know, Satan may tempt him to hit him and thus he would fall into a pit of fire (Hell)}}
\hadithdefcmd{bukhari}{7073}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قُلْتُ لِعَمْرٍو يَا أَبَا مُحَمَّدٍ سَمِعْتَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَرَّ رَجُلٌ بِسِهَامٍ فِي الْمَسْجِدِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكْ بِنِصَالِهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏\hadithno{7073}\hadithtrans{Narrated Sufyan:I said to `Amr, "O Abu Muhammad! Did you hear Jabir bin `Abdullah saying, 'A man carrying arrows passed through the mosque and Allah's Messenger (ﷺ) said to him, 'Hold the arrows by their heads! "`Amr replied, "Yes}}
\hadithdefcmd{bukhari}{7074}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مَرَّ فِي الْمَسْجِدِ بِأَسْهُمٍ قَدْ أَبْدَى نُصُولَهَا، فَأُمِرَ أَنْ يَأْخُذَ بِنُصُولِهَا، لاَ يَخْدِشُ مُسْلِمًا‏.‏\hadithno{7074}\hadithtrans{Narrated Jabir:A man passed through the mosque and he was carrying arrows, the heads of which were exposed (protruding). The man was ordered (by the Prophet) to hold the iron heads so that it might not scratch (injure) any Muslim}}
\hadithdefcmd{bukhari}{7075}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَرَّ أَحَدُكُمْ فِي مَسْجِدِنَا أَوْ فِي سُوقِنَا وَمَعَهُ نَبْلٌ فَلْيُمْسِكْ عَلَى نِصَالِهَا ـ أَوْ قَالَ فَلْيَقْبِضْ بِكَفِّهِ ـ أَنْ يُصِيبَ أَحَدًا مِنَ الْمُسْلِمِينَ مِنْهَا شَىْءٌ ‏"‏‏.‏\hadithno{7075}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "If anyone of you passed through our mosque or through our market while carrying arrows, he should hold the iron heads," or said, "..... he should hold (their heads) firmly with his hand lest he should injure one of the Muslims with it}}
\hadithdefcmd{bukhari}{7076}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ، وَقِتَالُهُ كُفْرٌ ‏"‏‏.‏\hadithno{7076}\hadithtrans{Narrated `Abdullah:The Prophet, said, "Abusing a Muslim is Fusuq (evil doing) and killing him is Kufr (disbelief)}}
\hadithdefcmd{bukhari}{7077}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي وَاقِدٌ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{7077}\hadithtrans{Narrated Ibn `Umar:I heard the Prophet (ﷺ) saying, "Do not revert to disbelief after me by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{7078}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا ابْنُ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، وَعَنْ رَجُلٍ، آخَرَ هُوَ أَفْضَلُ فِي نَفْسِي مِنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنْ أَبِي بَكْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ النَّاسَ فَقَالَ ‏"‏ أَلاَ تَدْرُونَ أَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ بِيَوْمِ النَّحْرِ ‏"‏‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَىُّ بَلَدٍ، هَذَا أَلَيْسَتْ بِالْبَلْدَةِ ‏"‏‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ، وَأَمْوَالَكُمْ، وَأَعْرَاضَكُمْ، وَأَبْشَارَكُمْ عَلَيْكُمْ حَرَامٌ، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا، أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏ قُلْنَا نَعَمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ، فَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ، فَإِنَّهُ رُبَّ مُبَلِّغٍ يُبَلِّغُهُ مَنْ هُوَ أَوْعَى لَهُ فَكَانَ كَذَلِكَ ـ قَالَ ـ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏ فَلَمَّا كَانَ يَوْمَ حُرِّقَ ابْنُ الْحَضْرَمِيِّ، حِينَ حَرَّقَهُ جَارِيَةُ بْنُ قُدَامَةَ‏.‏ قَالَ أَشْرِفُوا عَلَى أَبِي بَكْرَةَ‏.‏ فَقَالُوا هَذَا أَبُو بَكْرَةَ يَرَاكَ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ فَحَدَّثَتْنِي أُمِّي عَنْ أَبِي بَكْرَةَ أَنَّهُ قَالَ لَوْ دَخَلُوا عَلَىَّ مَا بَهَشْتُ بِقَصَبَةٍ‏.‏\hadithno{7078}\hadithtrans{Narrated Abu Bakra:Allah's Messenger (ﷺ) addressed the people saying, "Don't you know what is the day today?" They replied, "Allah and His Apostle know better." We thought that he might give that day another name. The Prophet said, "Isn't it the day of An-Nahr?" We replied, "Yes. O Allah's Messenger (ﷺ)." He then said, "What town is this? Isn't it the forbidden (Sacred) Town (Mecca)?" We replied, "Yes, O Allah's Messenger (ﷺ)." He then said, "Your blood, your properties, your honors and your skins (i.e., bodies) are as sacred to one another like the sanctity of this day of yours in this month of yours in this town of yours. (Listen) Haven't I conveyed Allah's message to you?" We replied, "Yes" He said, "O Allah! Be witness (for it). So it is incumbent upon those who are present to convey it (this message of mine) to those who are absent because the informed one might comprehend what I have said better than the present audience who will convey it to him.)" The narrator added: In fact, it was like that. The Prophet (ﷺ) added, "Beware! Do not renegade as disbelievers after me by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{7079}{حَدَّثَنَا أَحْمَدُ بْنُ إِشْكَابٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَرْتَدُّوا بَعْدِي كُفَّارًا، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{7079}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Beware! Do not renegade as (disbelievers) after me by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{7080}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَدِّهِ، جَرِيرٍ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ ‏"‏ اسْتَنْصِتِ النَّاسَ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{7080}\hadithtrans{Narrated Jarir:The Prophet (ﷺ) said to me during Hajjat-al-Wada`, "Let the people keep quiet and listen." Then he said (addressing the people), "Beware! Do not renegade as disbelievers after me by striking (cutting) the necks of one another}}
\hadithdefcmd{bukhari}{7081}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ،‏.‏ قَالَ إِبْرَاهِيمُ وَحَدَّثَنِي صَالِحُ بْنُ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَتَكُونُ فِتَنٌ الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ، وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي، وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي، مَنْ تَشَرَّفَ لَهَا تَسْتَشْرِفْهُ، فَمَنْ وَجَدَ فِيهَا مَلْجَأً أَوْ مَعَاذًا فَلْيَعُذْ بِهِ ‏"‏‏.‏\hadithno{7081}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There will be afflictions (in the near future) during which a sitting person will be better than a standing one, and the standing one will be better than the walking one, and the walking one will be better than the running one, and whoever will expose himself to these afflictions, they will destroy him. So whoever can find a place of protection or refuge from them, should take shelter in it}}
\hadithdefcmd{bukhari}{7082}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَتَكُونُ فِتَنٌ الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ، وَالْقَائِمُ خَيْرٌ مِنَ الْمَاشِي، وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي، مَنْ تَشَرَّفَ لَهَا تَسْتَشْرِفْهُ، فَمَنْ وَجَدَ مَلْجَأً أَوْ مَعَاذًا فَلْيَعُذْ بِهِ ‏"‏‏.‏\hadithno{7082}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There will be afflictions (in the near future) during which a sitting person will be better than a standing one, and the standing one will be better than a walking one, and the walking one will be better than a running one, and whoever will expose himself to these afflictions, they will destroy him. So whoever can find a place of protection or refuge from them, should take shelter in it}}
\hadithdefcmd{bukhari}{7083}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادٌ، عَنْ رَجُلٍ، لَمْ يُسَمِّهِ عَنِ الْحَسَنِ، قَالَ خَرَجْتُ بِسِلاَحِي لَيَالِيَ الْفِتْنَةِ فَاسْتَقْبَلَنِي أَبُو بَكْرَةَ فَقَالَ أَيْنَ تُرِيدُ قُلْتُ أُرِيدُ نُصْرَةَ ابْنِ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَكِلاَهُمَا مِنْ أَهْلِ النَّارِ ‏"‏‏.‏ قِيلَ فَهَذَا الْقَاتِلُ، فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏‏.‏ قَالَ حَمَّادُ بْنُ زَيْدٍ فَذَكَرْتُ هَذَا الْحَدِيثَ لأَيُّوبَ وَيُونُسَ بْنِ عُبَيْدٍ وَأَنَا أُرِيدُ أَنْ يُحَدِّثَانِي بِهِ فَقَالاَ إِنَّمَا رَوَى هَذَا الْحَدِيثَ الْحَسَنُ عَنِ الأَحْنَفِ بْنِ قَيْسٍ عَنْ أَبِي بَكْرَةَ‏.‏ حَدَّثَنَا سُلَيْمَانُ حَدَّثَنَا حَمَّادٌ بِهَذَا‏.‏ وَقَالَ مُؤَمَّلٌ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، وَيُونُسُ، وَهِشَامٌ، وَمُعَلَّى بْنُ زِيَادٍ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ مَعْمَرٌ عَنْ أَيُّوبَ‏.‏ وَرَوَاهُ بَكَّارُ بْنُ عَبْدِ الْعَزِيزِ عَنْ أَبِيهِ عَنْ أَبِي بَكْرَةَ‏.‏ وَقَالَ غُنْدَرٌ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَلَمْ يَرْفَعْهُ سُفْيَانُ عَنْ مَنْصُورٍ‏.‏\hadithno{7083}\hadithtrans{Narrated Al-Hasan:(Al-Ahnaf said:) I went out carrying my arms during the nights of the affliction (i.e. the war between `Ali and `Aisha) and Abu Bakra met me and asked, "Where are you going?" I replied, "I intend to help the cousin of Allah's Messenger (ﷺ) (i.e.,`Ali)." Abu Bakra said, "Allah's Messenger (ﷺ) said, 'If two Muslims take out their swords to fight each other, then both of them will be from amongst the people of the Hell- Fire.' It was said to the Prophet, 'It is alright for the killer but what about the killed one?' He replied, 'The killed one had the intention to kill his opponent.'" (See Hadith No. 30, Vol. 1) Narrated Al-Ahnaf: Abu Bakra said: The Prophet (ﷺ) said (as above)}}
\hadithdefcmd{bukhari}{7084}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ جَابِرٍ، حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ الْحَضْرَمِيُّ، أَنَّهُ سَمِعَ أَبَا إِدْرِيسَ الْخَوْلاَنِيَّ، أَنَّهُ سَمِعَ حُذَيْفَةَ بْنَ الْيَمَانِ، يَقُولُ كَانَ النَّاسُ يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْخَيْرِ، وَكُنْتُ أَسْأَلُهُ عَنِ الشَّرِّ، مَخَافَةَ أَنْ يُدْرِكَنِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا فِي جَاهِلِيَّةٍ وَشَرٍّ فَجَاءَنَا اللَّهُ بِهَذَا الْخَيْرِ، فَهَلْ بَعْدَ هَذَا الْخَيْرِ مِنْ شَرٍّ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ وَهَلْ بَعْدَ ذَلِكَ الشَّرِّ مِنْ خَيْرٍ قَالَ ‏"‏ نَعَمْ، وَفِيهِ دَخَنٌ ‏"‏‏.‏ قُلْتُ وَمَا دَخَنُهُ قَالَ ‏"‏ قَوْمٌ يَهْدُونَ بِغَيْرِ هَدْىٍ، تَعْرِفُ مِنْهُمْ وَتُنْكِرُ ‏"‏‏.‏ قُلْتُ فَهَلْ بَعْدَ ذَلِكَ الْخَيْرِ مِنْ شَرٍّ قَالَ ‏"‏ نَعَمْ، دُعَاةٌ عَلَى أَبْوَابِ جَهَنَّمَ، مَنْ أَجَابَهُمْ إِلَيْهَا قَذَفُوهُ فِيهَا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ صِفْهُمْ لَنَا‏.‏ قَالَ ‏"‏ هُمْ مِنْ جِلْدَتِنَا، وَيَتَكَلَّمُونَ بِأَلْسِنَتِنَا ‏"‏‏.‏ قُلْتُ فَمَا تَأْمُرُنِي إِنْ أَدْرَكَنِي ذَلِكَ قَالَ ‏"‏ تَلْزَمُ جَمَاعَةَ الْمُسْلِمِينَ وَإِمَامَهُمْ ‏"‏‏.‏ قُلْتُ فَإِنْ لَمْ يَكُنْ لَهُمْ جَمَاعَةٌ وَلاَ إِمَامٌ قَالَ ‏"‏ فَاعْتَزِلْ تِلْكَ الْفِرَقَ كُلَّهَا، وَلَوْ أَنْ تَعَضَّ بِأَصْلِ شَجَرَةٍ، حَتَّى يُدْرِكَكَ الْمَوْتُ، وَأَنْتَ عَلَى ذَلِكَ ‏"‏‏.‏\hadithno{7084}\hadithtrans{Narrated Hudhaifa bin Al-Yaman:The people used to ask Allah's Messenger (ﷺ) about the good but I used to ask him about the evil lest I should be overtaken by them. So I said, "O Allah's Messenger (ﷺ)! We were living in ignorance and in an (extremely) worst atmosphere, then Allah brought to us this good (i.e., Islam); will there be any evil after this good?" He said, "Yes." I said, 'Will there be any good after that evil?" He replied, "Yes, but it will be tainted (not pure.)'' I asked, "What will be its taint?" He replied, "(There will be) some people who will guide others not according to my tradition? You will approve of some of their deeds and disapprove of some others." I asked, "Will there be any evil after that good?" He replied, "Yes, (there will be) some people calling at the gates of the (Hell) Fire, and whoever will respond to their call, will be thrown by them into the (Hell) Fire." I said, "O Allah's Apostle! Will you describe them to us?" He said, "They will be from our own people and will speak our language." I said, "What do you order me to do if such a state should take place in my life?" He said, "Stick to the group of Muslims and their Imam (ruler)." I said, "If there is neither a group of Muslims nor an Imam (ruler)?" He said, "Then turn away from all those sects even if you were to bite (eat) the roots of a tree till death overtakes you while you are in that state}}
\hadithdefcmd{bukhari}{7085}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، وَغَيْرُهُ، قَالاَ حَدَّثَنَا أَبُو الأَسْوَدِ،‏.‏ وَقَالَ اللَّيْثُ عَنْ أَبِي الأَسْوَدِ، قَالَ قُطِعَ عَلَى أَهْلِ الْمَدِينَةِ بَعْثٌ فَاكْتُتِبْتُ فِيهِ فَلَقِيتُ عِكْرِمَةَ فَأَخْبَرْتُهُ فَنَهَانِي أَشَدَّ النَّهْىِ ثُمَّ قَالَ أَخْبَرَنِي ابْنُ عَبَّاسٍ أَنَّ أُنَاسًا مِنَ الْمُسْلِمِينَ كَانُوا مَعَ الْمُشْرِكِينَ يُكَثِّرُونَ سَوَادَ الْمُشْرِكِينَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَأْتِي السَّهْمُ فَيُرْمَى فَيُصِيبُ أَحَدَهُمْ، فَيَقْتُلُهُ أَوْ يَضْرِبُهُ فَيَقْتُلُهُ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ تَوَفَّاهُمُ الْمَلاَئِكَةُ ظَالِمِي أَنْفُسِهِمْ‏\}‏\hadithno{7085}\hadithtrans{Narrated Abu Al-Aswad:An army unit was being recruited from the people of Medina and my name was written among them. Then I met `Ikrima, and when I informed him about it, he discouraged me very strongly and said, "Ibn `Abbas told me that there were some Muslims who were with the pagans to increase their number against Allah's Messenger (ﷺ) (and the Muslim army) so arrows (from the Muslim army) would hit one of them and kill him or a Muslim would strike him (with his sword) and kill him. So Allah revealed:-- 'Verily! As for those whom the angels take (in death) while they are wronging themselves (by staying among the disbelievers)}}
\hadithdefcmd{bukhari}{7086}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ زَيْدِ بْنِ وَهْبٍ، حَدَّثَنَا حُذَيْفَةُ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَيْنِ رَأَيْتُ أَحَدَهُمَا وَأَنَا أَنْتَظِرُ الآخَرَ حَدَّثَنَا ‏"‏ أَنَّ الأَمَانَةَ نَزَلَتْ فِي جَذْرِ قُلُوبِ الرِّجَالِ، ثُمَّ عَلِمُوا مِنَ الْقُرْآنِ، ثُمَّ عَلِمُوا مِنَ السُّنَّةِ ‏"‏‏.‏ وَحَدَّثَنَا عَنْ رَفْعِهَا قَالَ ‏"‏ يَنَامُ الرَّجُلُ النَّوْمَةَ فَتُقْبَضُ الأَمَانَةُ مِنْ قَلْبِهِ، فَيَظَلُّ أَثَرُهَا مِثْلَ أَثَرِ الْوَكْتِ، ثُمَّ يَنَامُ النَّوْمَةَ فَتُقْبَضُ فَيَبْقَى فِيهَا أَثَرُهَا مِثْلَ أَثَرِ الْمَجْلِ، كَجَمْرٍ دَحْرَجْتَهُ عَلَى رِجْلِكَ فَنَفِطَ، فَتَرَاهُ مُنْتَبِرًا وَلَيْسَ فِيهِ شَىْءٌ، وَيُصْبِحُ النَّاسُ يَتَبَايَعُونَ فَلاَ يَكَادُ أَحَدٌ يُؤَدِّي الأَمَانَةَ فَيُقَالُ إِنَّ فِي بَنِي فُلاَنٍ رَجُلاً أَمِينًا‏.‏ وَيُقَالُ لِلرَّجُلِ مَا أَعْقَلَهُ، وَمَا أَظْرَفَهُ، وَمَا أَجْلَدَهُ، وَمَا فِي قَلْبِهِ مِثْقَالُ حَبَّةِ خَرْدَلٍ مِنْ إِيمَانٍ، وَلَقَدْ أَتَى عَلَىَّ زَمَانٌ، وَلاَ أُبَالِي أَيُّكُمْ بَايَعْتُ، لَئِنْ كَانَ مُسْلِمًا رَدَّهُ عَلَىَّ الإِسْلاَمُ، وَإِنْ كَانَ نَصْرَانِيًّا رَدَّهُ عَلَىَّ سَاعِيهِ، وَأَمَّا الْيَوْمَ فَمَا كُنْتُ أُبَايِعُ إِلاَّ فُلاَنًا وَفُلاَنًا ‏"‏‏.‏\hadithno{7086}\hadithtrans{Narrated Hudhaifa:Allah's Messenger (ﷺ) related to us, two prophetic narrations one of which I have seen fulfilled and I am waiting for the fulfillment of the other. The Prophet (ﷺ) told us that the virtue of honesty descended in the roots of men's hearts (from Allah) and then they learned it from the Qur'an and then they learned it from the Sunna (the Prophet's traditions). The Prophet (ﷺ) further told us how that honesty will be taken away: He said: "Man will go to sleep during which honesty will be taken away from his heart and only its trace will remain in his heart like the trace of a dark spot; then man will go to sleep, during which honesty will decrease further still, so that its trace will resemble the trace of blister as when an ember is dropped on one's foot which would make it swell, and one would see it swollen but there would be nothing inside. People would be carrying out their trade but hardly will there be a trustworthy person. It will be said, 'in such-and-such tribe there is an honest man,' and later it will be said about some man, 'What a wise, polite and strong man he is!' Though he will not have faith equal even to a mustard seed in his heart." No doubt, there came upon me a time when I did not mind dealing (bargaining) with anyone of you, for if he was a Muslim his Islam would compel him to pay me what is due to me, and if he was a Christian, the Muslim official would compel him to pay me what is due to me, but today I do not deal except with such-and-such person}}
\hadithdefcmd{bukhari}{7087}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّهُ دَخَلَ عَلَى الْحَجَّاجِ فَقَالَ يَا ابْنَ الأَكْوَعِ ارْتَدَدْتَ عَلَى عَقِبَيْكَ تَعَرَّبْتَ قَالَ لاَ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذِنَ لِي فِي الْبَدْوِ‏.‏ وَعَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ قَالَ لَمَّا قُتِلَ عُثْمَانُ بْنُ عَفَّانَ خَرَجَ سَلَمَةُ بْنُ الأَكْوَعِ إِلَى الرَّبَذَةِ، وَتَزَوَّجَ هُنَاكَ امْرَأَةً وَوَلَدَتْ لَهُ أَوْلاَدًا، فَلَمْ يَزَلْ بِهَا حَتَّى قَبْلَ أَنْ يَمُوتَ بِلَيَالٍ، فَنَزَلَ الْمَدِينَةَ‏.‏\hadithno{7087}\hadithtrans{Narrated Salama bin Al-Akwa`:That he visited Al-Hajjaj (bin Yusuf). Al-Hajjaj said, "O son of Al-Akwa`! You have turned on your heels (i.e., deserted Islam) by staying (in the desert) with the bedouins." Salama replied, "No, but Allah's Messenger (ﷺ) allowed me to stay with the bedouin in the desert." Narrated Yazid bin Abi Ubaid: When `Uthman bin `Affan was killed (martyred), Salama bin Al-Akwa` went out to a place called Ar- Rabadha and married there and begot children, and he stayed there till a few nights before his death when he came to Medina}}
\hadithdefcmd{bukhari}{7088}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ أَنْ يَكُونَ خَيْرَ مَالِ الْمُسْلِمِ غَنَمٌ، يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ، يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏‏.‏\hadithno{7088}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "There will come a time when the best property of a Muslim will be sheep which he will take to the tops of mountains and the places of rainfall so as to flee with his religion from the afflictions}}
\hadithdefcmd{bukhari}{7089}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ سَأَلُوا النَّبِيَّ صلى الله عليه وسلم حَتَّى أَحْفَوْهُ بِالْمَسْأَلَةِ، فَصَعِدَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ يَوْمٍ الْمِنْبَرَ فَقَالَ ‏"‏ لاَ تَسْأَلُونِي عَنْ شَىْءٍ إِلاَّ بَيَّنْتُ لَكُمْ ‏"‏‏.‏ فَجَعَلْتُ أَنْظُرُ يَمِينًا وَشِمَالاً، فَإِذَا كُلُّ رَجُلٍ رَأْسُهُ فِي ثَوْبِهِ يَبْكِي، فَأَنْشَأَ رَجُلٌ كَانَ إِذَا لاَحَى يُدْعَى إِلَى غَيْرِ أَبِيهِ فَقَالَ يَا نَبِيَّ اللَّهِ مَنْ أَبِي فَقَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ ثُمَّ أَنْشَأَ عُمَرُ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا، وَبِالإِسْلاَمِ دِينًا، وَبِمُحَمَّدٍ رَسُولاً، نَعُوذُ بِاللَّهِ مِنْ سُوءِ الْفِتَنِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا رَأَيْتُ فِي الْخَيْرِ وَالشَّرِّ كَالْيَوْمِ قَطُّ، إِنَّهُ صُوِّرَتْ لِي الْجَنَّةُ وَالنَّارُ حَتَّى رَأَيْتُهُمَا دُونَ الْحَائِطِ ‏"‏‏.‏ قَالَ قَتَادَةُ يُذْكَرُ هَذَا الْحَدِيثُ عِنْدَ هَذِهِ الآيَةِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏\hadithno{7089}\hadithtrans{Narrated Anas:The people started asking the Prophet (ﷺ) too many questions importunately. So one day he ascended the pulpit and said, "You will not ask me any question but I will explain it to you." I looked right and left, and behold, every man was covering his head with his garment and weeping. Then got up a man who, whenever quarreling with somebody, used to be accused of not being the son of his father. He said, "O Allah's Messenger (ﷺ)! Who is my father?" The Prophet (ﷺ) replied, "Your father is Hudhaifa." Then `Umar got up and said, "We accept Allah as our Lord, Islam as our religion and Muhammad as our Apostle and we seek refuge with Allah from the evil of afflictions." The Prophet (ﷺ) said, " I have never seen the good and bad like on this day. No doubt, Paradise and Hell was displayed in front of me till I saw them in front of that wall," Qatada said: This Hadith used to be mentioned as an explanation of this Verse:-- 'O you who believe! Ask not questions about things which, if made plain to you, may cause you trouble}}
\hadithdefcmd{bukhari}{7090}{وَقَالَ عَبَّاسٌ النَّرْسِيُّ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسًا، حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم بِهَذَا وَقَالَ كُلُّ رَجُلٍ لاَفًّا رَأْسَهُ فِي ثَوْبِهِ يَبْكِي‏.‏ وَقَالَ عَائِذًا بِاللَّهِ مِنْ سُوءِ الْفِتَنِ‏.‏ أَوْ قَالَ أَعُوذُ بِاللَّهِ مِنْ سُوءِ الْفِتَنِ‏.‏\hadithno{7090}\hadithtrans{The the above hadith was narrated by Anas through another chain and said (with the wording) "and every man had his head wrapped in his garment and weeping". And he said (with the wording) "seeking refuge with Allah from the evil of afflictions" or he said "I seek refuge with Allah from the evil of afflictions}}
\hadithdefcmd{bukhari}{7091}{وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، وَمُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا، حَدَّثَهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا وَقَالَ عَائِذًا بِاللَّهِ مِنْ شَرِّ الْفِتَنِ‏.‏\hadithno{7091}\hadithtrans{Narrated Anas:The above hadith is narrated on the authority of Anas thorugh another chain and he said (with the wording) "seeking refuge with Allah from the evil of afflictions}}
\hadithdefcmd{bukhari}{7092}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَامَ إِلَى جَنْبِ الْمِنْبَرِ فَقَالَ ‏"‏ الْفِتْنَةُ هَا هُنَا الْفِتْنَةُ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ قَرْنُ الشَّمْسِ ‏"‏‏.‏\hadithno{7092}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) stood up beside the pulpit (and pointed with his finger towards the East) and said, "Afflictions are there! Afflictions are there, from where the side of the head of Satan comes out," or said, "..the side of the sun}}
\hadithdefcmd{bukhari}{7093}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ مُسْتَقْبِلٌ الْمَشْرِقَ يَقُولُ ‏ "‏ أَلاَ إِنَّ الْفِتْنَةَ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏‏.‏\hadithno{7093}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ) while he was facing the East, saying, "Verily! Afflictions are there, from where the side of the head of Satan comes out}}
\hadithdefcmd{bukhari}{7094}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَكَرَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَارِكْ لَنَا فِي شَأْمِنَا، اللَّهُمَّ بَارِكْ لَنَا فِي يَمَنِنَا ‏"‏‏.‏ قَالُوا وَفِي نَجْدِنَا‏.‏ قَالَ ‏"‏ اللَّهُمَّ بَارِكْ لَنَا فِي شَأْمِنَا، اللَّهُمَّ بَارِكْ لَنَا فِي يَمَنِنَا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَفِي نَجْدِنَا فَأَظُنُّهُ قَالَ فِي الثَّالِثَةَ ‏"‏ هُنَاكَ الزَّلاَزِلُ وَالْفِتَنُ، وَبِهَا يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏‏.‏\hadithno{7094}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "O Allah! Bestow Your blessings on our Sham! O Allah! Bestow Your blessings on our Yemen." The People said, "And also on our Najd." He said, "O Allah! Bestow Your blessings on our Sham (north)! O Allah! Bestow Your blessings on our Yemen." The people said, "O Allah's Apostle! And also on our Najd." I think the third time the Prophet (ﷺ) said, "There (in Najd) is the place of earthquakes and afflictions and from there comes out the side of the head of Satan}}
\hadithdefcmd{bukhari}{7095}{حَدَّثَنَا إِسْحَاقُ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ بَيَانٍ، عَنْ وَبَرَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ خَرَجَ عَلَيْنَا عَبْدُ اللَّهِ بْنُ عُمَرَ فَرَجَوْنَا أَنْ يُحَدِّثَنَا، حَدِيثًا حَسَنًا ـ قَالَ ـ فَبَادَرَنَا إِلَيْهِ رَجُلٌ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ حَدِّثْنَا عَنِ الْقِتَالِ فِي الْفِتْنَةِ وَاللَّهُ يَقُولُ ‏\{‏وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ‏\}‏ فَقَالَ هَلْ تَدْرِي مَا الْفِتْنَةُ ثَكِلَتْكَ أُمُّكَ، إِنَّمَا كَانَ مُحَمَّدٌ صلى الله عليه وسلم يُقَاتِلُ الْمُشْرِكِينَ، وَكَانَ الدُّخُولُ فِي دِينِهِمْ فِتْنَةً، وَلَيْسَ كَقِتَالِكُمْ عَلَى الْمُلْكِ‏.‏\hadithno{7095}\hadithtrans{Narrated Sa`id bin Jubair:`Abdullah bin `Umar came to us and we hoped that he would narrate to us a good Hadith. But before we asked him, a man got up and said to him, "O Abu `Abdur-Rahman! Narrate to us about the battles during the time of the afflictions, as Allah says:-- 'And fight them until there is no more afflictions (i.e. no more worshipping of others besides Allah).'" (2.193) Ibn `Umar said (to the man), "Do you know what is meant by afflictions? Let your mother bereave you! Muhammad used to fight against the pagans, for a Muslim was put to trial in his religion (The pagans will either kill him or chain him as a captive). His fighting was not like your fighting which is carried on for the sake of ruling}}
\hadithdefcmd{bukhari}{7096}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، سَمِعْتُ حُذَيْفَةَ، يَقُولُ بَيْنَا نَحْنُ جُلُوسٌ عِنْدَ عُمَرَ قَالَ أَيُّكُمْ يَحْفَظُ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فِي الْفِتْنَةِ‏.‏ قَالَ ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَوَلَدِهِ وَجَارِهِ، تُكَفِّرُهَا الصَّلاَةُ وَالصَّدَقَةُ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏‏.‏ قَالَ لَيْسَ عَنْ هَذَا أَسْأَلُكَ، وَلَكِنِ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ‏.‏ قَالَ لَيْسَ عَلَيْكَ مِنْهَا بَأْسٌ يَا أَمِيرَ الْمُؤْمِنِينَ، إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا‏.‏ قَالَ عُمَرُ أَيُكْسَرُ الْبَابُ أَمْ يُفْتَحُ قَالَ بَلْ يُكْسَرُ‏.‏ قَالَ عُمَرُ إِذًا لاَ يُغْلَقَ أَبَدًا‏.‏ قُلْتُ أَجَلْ‏.‏ قُلْنَا لِحُذَيْفَةَ أَكَانَ عُمَرُ يَعْلَمُ الْبَابَ قَالَ نَعَمْ كَمَا أَعْلَمُ أَنَّ دُونَ غَدٍ لَيْلَةً، وَذَلِكَ أَنِّي حَدَّثْتُهُ حَدِيثًا لَيْسَ بِالأَغَالِيطِ‏.‏ فَهِبْنَا أَنْ نَسْأَلَهُ مَنِ الْبَابُ فَأَمَرْنَا مَسْرُوقًا فَسَأَلَهُ فَقَالَ مَنِ الْبَابُ قَالَ عُمَرُ‏.‏\hadithno{7096}\hadithtrans{Narrated Shaqiq:I heard Hudhaifa saying, "While we were sitting with `Umar, he said, 'Who among you remembers the statement of the Prophet (ﷺ) about the afflictions?' Hudhaifa said, "The affliction of a man in his family, his property, his children and his neighbors are expiated by his prayers, Zakat (and alms) and enjoining good and forbidding evil." `Umar said, "I do not ask you about these afflictions, but about those afflictions which will move like the waves of the sea." Hudhaifa said, "Don't worry about it, O chief of the believers, for there is a closed door between you and them." `Umar said, "Will that door be broken or opened?" I said, "No. it will be broken." `Umar said, "Then it will never be closed," I said, "Yes." We asked Hudhaifa, "Did `Umar know what that door meant?" He replied, "Yes, as I know that there will be night before tomorrow morning, that is because I narrated to him a true narration free from errors." We dared not ask Hudhaifa as to whom the door represented so we ordered Masruq to ask him what does the door stand for? He replied, "`Umar}}
\hadithdefcmd{bukhari}{7097}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى حَائِطٍ مِنْ حَوَائِطِ الْمَدِينَةِ لِحَاجَتِهِ، وَخَرَجْتُ فِي إِثْرِهِ، فَلَمَّا دَخَلَ الْحَائِطَ جَلَسْتُ عَلَى بَابِهِ وَقُلْتُ لأَكُونَنَّ الْيَوْمَ بَوَّابَ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَأْمُرْنِي فَذَهَبَ النَّبِيُّ صلى الله عليه وسلم وَقَضَى حَاجَتَهُ، وَجَلَسَ عَلَى قُفِّ الْبِئْرِ، فَكَشَفَ عَنْ سَاقَيْهِ وَدَلاَّهُمَا فِي الْبِئْرِ، فَجَاءَ أَبُو بَكْرٍ يَسْتَأْذِنُ عَلَيْهِ لِيَدْخُلَ فَقُلْتُ كَمَا أَنْتَ حَتَّى أَسْتَأْذِنَ لَكَ، فَوَقَفَ فَجِئْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا نَبِيَّ اللَّهِ أَبُو بَكْرٍ يَسْتَأْذِنُ عَلَيْكَ‏.‏ قَالَ ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَدَخَلَ فَجَاءَ عَنْ يَمِينِ النَّبِيِّ صلى الله عليه وسلم فَكَشَفَ عَنْ سَاقَيْهِ وَدَلاَّهُمَا فِي الْبِئْرِ، فَجَاءَ عُمَرُ فَقُلْتُ كَمَا أَنْتَ حَتَّى أَسْتَأْذِنَ لَكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَجَاءَ عَنْ يَسَارِ النَّبِيِّ صلى الله عليه وسلم فَكَشَفَ عَنْ سَاقَيْهِ فَدَلاَّهُمَا فِي الْبِئْرِ، فَامْتَلأَ الْقُفُّ فَلَمْ يَكُنْ فِيهِ مَجْلِسٌ، ثُمَّ جَاءَ عُثْمَانُ فَقُلْتُ كَمَا أَنْتَ حَتَّى أَسْتَأْذِنَ لَكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ، مَعَهَا بَلاَءٌ يُصِيبُهُ ‏"‏‏.‏ فَدَخَلَ فَلَمْ يَجِدْ مَعَهُمْ مَجْلِسًا، فَتَحَوَّلَ حَتَّى جَاءَ مُقَابِلَهُمْ عَلَى شَفَةِ الْبِئْرِ، فَكَشَفَ عَنْ سَاقَيْهِ ثُمَّ دَلاَّهُمَا فِي الْبِئْرِ‏.‏ فَجَعَلْتُ أَتَمَنَّى أَخًا لِي وَأَدْعُو اللَّهَ أَنْ يَأْتِيَ‏.‏ قَالَ ابْنُ الْمُسَيَّبِ فَتَأَوَّلْتُ ذَلِكَ قُبُورَهُمُ اجْتَمَعَتْ هَا هُنَا وَانْفَرَدَ عُثْمَانُ‏.‏\hadithno{7097}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) went out to one of the gardens of Medina for some business and I went out to follow him. When he entered the garden, I sat at its gate and said to myself, "To day I will be the gatekeeper of the Prophet though he has not ordered me." The Prophet (ﷺ) went and finished his need and went to sit on the constructed edge of the well and uncovered his legs and hung them in the well. In the meantime Abu Bakr came and asked permission to enter. I said (to him), "Wait till I get you permission." Abu Bakr waited outside and I went to the Prophet (ﷺ) and said, "O Allah's Prophet! Abu Bakr asks your permission to enter." He said, "Admit him, and give him the glad tidings of entering Paradise." So Abu Bakr entered and sat on the right side of the Prophet (ﷺ) and uncovered his legs and hung them in the well. Then `Umar came and I said (to him), "Wait till I get you permission." The Prophet (ﷺ) said, "Admit him and give him the glad tidings of entering Paradise." So `Umar entered and sat on the left side of the Prophet and uncovered his legs and hung them in the well so that one side of the well became fully occupied and there remained no place for any-one to sit. Then `Uthman came and I said (to him), "Wait till I get permission for you." The Prophet (ﷺ) said, "Admit him and give him the glad tidings of entering Paradise with a calamity which will befall him." When he entered, he could not find any place to sit with them so he went to the other edge of the well opposite them and uncovered his legs and hung them in the well. I wished that a brother of mine would come, so I invoked Allah for his coming. (Ibn Al-Musaiyab said, "I interpreted that (narration) as indicating their graves. The first three are together and the grave of `Uthman is separate from theirs}}
\hadithdefcmd{bukhari}{7098}{حَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، سَمِعْتُ أَبَا وَائِلٍ، قَالَ قِيلَ لأُسَامَةَ أَلاَ تُكَلِّمُ هَذَا‏.‏ قَالَ قَدْ كَلَّمْتُهُ مَا دُونَ أَنْ أَفْتَحَ بَابًا، أَكُونُ أَوَّلَ مَنْ يَفْتَحُهُ، وَمَا أَنَا بِالَّذِي أَقُولُ لِرَجُلٍ بَعْدَ أَنْ يَكُونَ أَمِيرًا عَلَى رَجُلَيْنِ أَنْتَ خَيْرٌ‏.‏ بَعْدَ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُجَاءُ بِرَجُلٍ فَيُطْرَحُ فِي النَّارِ، فَيَطْحَنُ فِيهَا كَطَحْنِ الْحِمَارِ بِرَحَاهُ، فَيُطِيفُ بِهِ أَهْلُ النَّارِ فَيَقُولُونَ أَىْ فُلاَنُ أَلَسْتَ كُنْتَ تَأْمُرُ بِالْمَعْرُوفِ، وَتَنْهَى عَنِ الْمُنْكَرِ فَيَقُولُ إِنِّي كُنْتُ آمُرُ بِالْمَعْرُوفِ وَلاَ أَفْعَلُهُ، وَأَنْهَى عَنِ الْمُنْكَرِ وَأَفْعَلُهُ ‏"‏‏.‏\hadithno{7098}\hadithtrans{Narrated Abu Wail:Someone said to Usama, "Will you not talk to this (Uthman)?" Usama said, "I talked to him (secretly) without being the first man to open an evil door. I will never tell a ruler who rules over two men or more that he is good after I heard Allah's Messenger (ﷺ) saying, 'A man will be brought and put in Hell (Fire) and he will circumambulate (go around and round) in Hell (Fire) like a donkey of a (flour) grinding mill, and all the people of Hell (Fire) will gather around him and will say to him, O so-and-so! Didn't you use to order others for good and forbid them from evil?' That man will say, 'I used to order others to do good but I myself never used to do it, and I used to forbid others from evil while I myself used to do evil}}
\hadithdefcmd{bukhari}{7099}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، حَدَّثَنَا عَوْفٌ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ لَقَدْ نَفَعَنِي اللَّهُ بِكَلِمَةٍ أَيَّامَ الْجَمَلِ لَمَّا بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنَّ فَارِسًا مَلَّكُوا ابْنَةَ كِسْرَى قَالَ ‏ "‏ لَنْ يُفْلِحَ قَوْمٌ وَلَّوْا أَمْرَهُمُ امْرَأَةً ‏"‏‏.‏\hadithno{7099}\hadithtrans{Narrated Abu Bakra:During the battle of Al-Jamal, Allah benefited me with a Word (I heard from the Prophet). When the Prophet heard the news that the people of the Persia had made the daughter of Khosrau their Queen (ruler), he said, "Never will succeed such a nation as makes a woman their ruler}}
\hadithdefcmd{bukhari}{7100}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو حَصِينٍ، حَدَّثَنَا أَبُو مَرْيَمَ عَبْدُ اللَّهِ بْنُ زِيَادٍ الأَسَدِيُّ، قَالَ لَمَّا سَارَ طَلْحَةُ وَالزُّبَيْرُ وَعَائِشَةُ إِلَى الْبَصْرَةِ بَعَثَ عَلِيٌّ عَمَّارَ بْنَ يَاسِرٍ وَحَسَنَ بْنَ عَلِيٍّ، فَقَدِمَا عَلَيْنَا الْكُوفَةَ فَصَعِدَا الْمِنْبَرَ، فَكَانَ الْحَسَنُ بْنُ عَلِيٍّ فَوْقَ الْمِنْبَرِ فِي أَعْلاَهُ، وَقَامَ عَمَّارٌ أَسْفَلَ مِنَ الْحَسَنِ، فَاجْتَمَعْنَا إِلَيْهِ فَسَمِعْتُ عَمَّارًا يَقُولُ إِنَّ عَائِشَةَ قَدْ سَارَتْ إِلَى الْبَصْرَةِ، وَوَاللَّهِ إِنَّهَا لَزَوْجَةُ نَبِيِّكُمْ صلى الله عليه وسلم فِي الدُّنْيَا وَالآخِرَةِ، وَلَكِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى ابْتَلاَكُمْ، لِيَعْلَمَ إِيَّاهُ تُطِيعُونَ أَمْ هِيَ‏.‏\hadithno{7100}\hadithtrans{Narrated Abu Maryam `Abdullah bin Ziyad Al-Aasadi:When Talha, Az-Zubair and `Aisha moved to Basra, `Ali sent `Ammar bin Yasir and Hasan bin `Ali who came to us at Kufa and ascended the pulpit. Al-Hasan bin `Ali was at the top of the pulpit and `Ammar was below Al-Hasan. We all gathered before him. I heard `Ammar saying, "`Aisha has moved to Al-Busra. By Allah! She is the wife of your Prophet in this world and in the Hereafter. But Allah has put you to test whether you obey Him (Allah) or her (`Aisha)}}
\hadithdefcmd{bukhari}{7101}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ أَبِي غَنِيَّةَ، عَنِ الْحَكَمِ، عَنْ أَبِي وَائِلٍ، قَامَ عَمَّارٌ عَلَى مِنْبَرِ الْكُوفَةِ، فَذَكَرَ عَائِشَةَ وَذَكَرَ مَسِيرَهَا وَقَالَ إِنَّهَا زَوْجَةُ نَبِيِّكُمْ صلى الله عليه وسلم فِي الدُّنْيَا وَالآخِرَةِ، وَلَكِنَّهَا مِمَّا ابْتُلِيتُمْ‏.‏\hadithno{7101}\hadithtrans{Narrated Abu Wail:`Ammar stood on the pulpit at Kufa and mentioned `Aisha and her coming (to Busra) and said, "She is the wife of your Prophet in this world and in the Hereafter, but you people are being put to test in this issue}}
\hadithdefcmd{bukhari}{7104}{حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي عَمْرٌو، سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ دَخَلَ أَبُو مُوسَى وَأَبُو مَسْعُودٍ عَلَى عَمَّارٍ حَيْثُ بَعَثَهُ عَلِيٌّ إِلَى أَهْلِ الْكُوفَةِ يَسْتَنْفِرُهُمْ فَقَالاَ مَا رَأَيْنَاكَ أَتَيْتَ أَمْرًا أَكْرَهَ عِنْدَنَا مِنْ إِسْرَاعِكَ فِي هَذَا الأَمْرِ مُنْذُ أَسْلَمْتَ‏.‏ فَقَالَ عَمَّارٌ مَا رَأَيْتُ مِنْكُمَا مُنْذُ أَسْلَمْتُمَا أَمْرًا أَكْرَهَ عِنْدِي مِنْ إِبْطَائِكُمَا عَنْ هَذَا الأَمْرِ‏.‏ وَكَسَاهُمَا حُلَّةً حُلَّةً، ثُمَّ رَاحُوا إِلَى الْمَسْجِدِ‏.‏\hadithno{7104}\hadithtrans{Narrated Abu Wail:Abu Musa and Abu Mas`ud went to `Ammar when `Ali had sent him to Kufa to exhort them to fight (on `Ali's side). They said to him, "Since you have become a Muslim, we have never seen you doing a deed more criticizable to us than your haste in this matter." `Ammar said, "Since you (both) became Muslims, I have never seen you doing a deed more criticizable to me than your keeping away from this matter." Then Abu Mas`ud provided `Ammar and Abu Musa with two-piece outfits to wear, and one of them went to the mosque (of Kufa)}}
\hadithdefcmd{bukhari}{7107}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، كُنْتُ جَالِسًا مَعَ أَبِي مَسْعُودٍ وَأَبِي مُوسَى وَعَمَّارٍ فَقَالَ أَبُو مَسْعُودٍ مَا مِنْ أَصْحَابِكَ أَحَدٌ إِلاَّ لَوْ شِئْتُ لَقُلْتُ فِيهِ غَيْرَكَ، وَمَا رَأَيْتُ مِنْكَ شَيْئًا مُنْذُ صَحِبْتَ النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنِ اسْتِسْرَاعِكَ فِي هَذَا الأَمْرِ‏.‏ قَالَ عَمَّارٌ يَا أَبَا مَسْعُودٍ وَمَا رَأَيْتُ مِنْكَ وَلاَ مِنْ صَاحِبِكَ هَذَا شَيْئًا مُنْذُ صَحِبْتُمَا النَّبِيَّ صلى الله عليه وسلم أَعْيَبَ عِنْدِي مِنْ إِبْطَائِكُمَا فِي هَذَا الأَمْرِ‏.‏ فَقَالَ أَبُو مَسْعُودٍ وَكَانَ مُوسِرًا يَا غُلاَمُ هَاتِ حُلَّتَيْنِ‏.‏ فَأَعْطَى إِحْدَاهُمَا أَبَا مُوسَى وَالأُخْرَى عَمَّارًا وَقَالَ رُوحَا فِيهِ إِلَى الْجُمُعَةِ‏.‏\hadithno{7107}\hadithtrans{Narrated Shaqiq bin Salama:I was sitting with Abu Mas`ud and Abu Musa and `Ammar. Abu Mas`ud said (to `Ammar), "There is none of your companions but, if I wish, I could find fault with him except with you. Since you joined the company of the Prophet (ﷺ) I have never seen anything done by you more criticizable by me than your haste in this issue." `Ammar said, O Abu Mas`ud ! I have never seen anything done by you or by this companion of yours (i.e., Abu Musa) more criticizable by me than your keeping away from this issue since the time you both joined the company of the Prophet." Then Abu Mas`ud who was a rich man, said (to his servant), "O boy! Bring two suits." Then he gave one to Abu Musa and the other to `Ammar and said (to them), "Put on these suits before going for the Friday prayer}}
\hadithdefcmd{bukhari}{7108}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْزَلَ اللَّهُ بِقَوْمٍ عَذَابًا، أَصَابَ الْعَذَابُ مَنْ كَانَ فِيهِمْ، ثُمَّ بُعِثُوا عَلَى أَعْمَالِهِمْ ‏"‏‏.‏\hadithno{7108}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "If Allah sends punishment upon a nation then it befalls upon the whole population indiscriminately and then they will be resurrected (and judged) according to their deeds}}
\hadithdefcmd{bukhari}{7109}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا إِسْرَائِيلُ أَبُو مُوسَى، وَلَقِيتُهُ، بِالْكُوفَةِ جَاءَ إِلَى ابْنِ شُبْرُمَةَ فَقَالَ أَدْخِلْنِي عَلَى عِيسَى فَأَعِظَهُ‏.‏ فَكَأَنَّ ابْنَ شُبْرُمَةَ خَافَ عَلَيْهِ فَلَمْ يَفْعَلْ‏.‏ قَالَ حَدَّثَنَا الْحَسَنُ قَالَ لَمَّا سَارَ الْحَسَنُ بْنُ عَلِيٍّ ـ رضى الله عنهما ـ إِلَى مُعَاوِيَةَ بِالْكَتَائِبِ‏.‏ قَالَ عَمْرُو بْنُ الْعَاصِ لِمُعَاوِيَةَ أَرَى كَتِيبَةً لاَ تُوَلِّي حَتَّى تُدْبِرَ أُخْرَاهَا‏.‏ قَالَ مُعَاوِيَةُ مَنْ لِذَرَارِيِّ الْمُسْلِمِينَ‏.‏ فَقَالَ أَنَا‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عَامِرٍ وَعَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ نَلْقَاهُ فَنَقُولُ لَهُ الصُّلْحَ‏.‏ قَالَ الْحَسَنُ وَلَقَدْ سَمِعْتُ أَبَا بَكْرَةَ قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ جَاءَ الْحَسَنُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ابْنِي هَذَا سَيِّدٌ وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ مِنَ الْمُسْلِمِينَ ‏"‏‏.‏\hadithno{7109}\hadithtrans{Narrated Al-Hasan Al-Basri:When Al-Hasan bin `Ali moved with army units against Muawiya, `Amr bin AL-As said to Muawiya, "I see an army that will not retreat unless and until the opposing army retreats." Muawiya said, "(If the Muslims are killed) who will look after their children?" `Amr bin Al-As said: I (will look after them). On that, `Abdullah bin 'Amir and `Abdur-Rahman bin Samura said, "Let us meet Muawiya and suggest peace." Al-Hasan Al-Basri added: No doubt, I heard that Abu Bakra said, "Once while the Prophet was addressing (the people), Al-Hasan (bin `Ali) came and the Prophet (ﷺ) said, 'This son of mine is a chief, and Allah may make peace between two groups of Muslims through him}}
\hadithdefcmd{bukhari}{7110}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ عَمْرٌو أَخْبَرَنِي مُحَمَّدُ بْنُ عَلِيٍّ، أَنَّ حَرْمَلَةَ، مَوْلَى أُسَامَةَ أَخْبَرَهُ قَالَ عَمْرٌو وَقَدْ رَأَيْتُ حَرْمَلَةَ قَالَ أَرْسَلَنِي أُسَامَةُ إِلَى عَلِيٍّ وَقَالَ إِنَّهُ سَيَسْأَلُكَ الآنَ فَيَقُولُ مَا خَلَّفَ صَاحِبَكَ فَقُلْ لَهُ يَقُولُ لَكَ لَوْ كُنْتَ فِي شِدْقِ الأَسَدِ لأَحْبَبْتُ أَنْ أَكُونَ مَعَكَ فِيهِ، وَلَكِنَّ هَذَا أَمْرٌ لَمْ أَرَهُ، فَلَمْ يُعْطِنِي شَيْئًا، فَذَهَبْتُ إِلَى حَسَنٍ وَحُسَيْنٍ وَابْنِ جَعْفَرٍ فَأَوْقَرُوا لِي رَاحِلَتِي‏.‏\hadithno{7110}\hadithtrans{Narrated Harmala:(Usama's Maula) Usama (bin Zaid) sent me to `Ali (at Kufa) and said, "`Ali will ask you, 'What has prevented your companion from joining me?' You then should say to him, 'If you (`Ali) were in the mouth of a lion, I would like to be with you, but in this matter I won't take any part.' " Harmala added: "`Ali didn't give me anything (when I conveyed the message to him) so I went to Hasan, Hussain and Ibn Ja`far and they loaded my camels with much (wealth)}}
\hadithdefcmd{bukhari}{7111}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ لَمَّا خَلَعَ أَهْلُ الْمَدِينَةِ يَزِيدَ بْنَ مُعَاوِيَةَ جَمَعَ ابْنُ عُمَرَ حَشَمَهُ وَوَلَدَهُ فَقَالَ إِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُنْصَبُ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ وَإِنَّا قَدْ بَايَعْنَا هَذَا الرَّجُلَ عَلَى بَيْعِ اللَّهِ وَرَسُولِهِ، وَإِنِّي لاَ أَعْلَمُ غَدْرًا أَعْظَمَ مِنْ أَنْ يُبَايَعَ رَجُلٌ عَلَى بَيْعِ اللَّهِ وَرَسُولِهِ، ثُمَّ يُنْصَبُ لَهُ الْقِتَالُ، وَإِنِّي لاَ أَعْلَمُ أَحَدًا مِنْكُمْ خَلَعَهُ، وَلاَ بَايَعَ فِي هَذَا الأَمْرِ، إِلاَّ كَانَتِ الْفَيْصَلَ بَيْنِي وَبَيْنَهُ‏.‏\hadithno{7111}\hadithtrans{Narrated Nafi`:When the people of Medina dethroned Yazid bin Muawiya, Ibn `Umar gathered his special friends and children and said, "I heard the Prophet (ﷺ) saying, 'A flag will be fixed for every betrayer on the Day of Resurrection,' and we have given the oath of allegiance to this person (Yazid) in accordance with the conditions enjoined by Allah and His Apostle and I do not know of anything more faithless than fighting a person who has been given the oath of allegiance in accordance with the conditions enjoined by Allah and His Apostle , and if ever I learn that any person among you has agreed to dethrone Yazid, by giving the oath of allegiance (to somebody else) then there will be separation between him and me}}
\hadithdefcmd{bukhari}{7112}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ عَوْفٍ، عَنْ أَبِي الْمِنْهَالِ، قَالَ لَمَّا كَانَ ابْنُ زِيَادٍ وَمَرْوَانُ بِالشَّأْمِ، وَوَثَبَ ابْنُ الزُّبَيْرِ بِمَكَّةَ، وَوَثَبَ الْقُرَّاءُ بِالْبَصْرَةِ، فَانْطَلَقْتُ مَعَ أَبِي إِلَى أَبِي بَرْزَةَ الأَسْلَمِيِّ حَتَّى دَخَلْنَا عَلَيْهِ فِي دَارِهِ وَهْوَ جَالِسٌ فِي ظِلِّ عُلِّيَّةٍ لَهُ مِنْ قَصَبٍ، فَجَلَسْنَا إِلَيْهِ فَأَنْشَأَ أَبِي يَسْتَطْعِمُهُ الْحَدِيثَ فَقَالَ يَا أَبَا بَرْزَةَ أَلاَ تَرَى مَا وَقَعَ فِيهِ النَّاسُ فَأَوَّلُ شَىْءٍ سَمِعْتُهُ تَكَلَّمَ بِهِ إِنِّي احْتَسَبْتُ عِنْدَ اللَّهِ أَنِّي أَصْبَحْتُ سَاخِطًا عَلَى أَحْيَاءِ قُرَيْشٍ، إِنَّكُمْ يَا مَعْشَرَ الْعَرَبِ كُنْتُمْ عَلَى الْحَالِ الَّذِي عَلِمْتُمْ مِنَ الذِّلَّةِ وَالْقِلَّةِ وَالضَّلاَلَةِ، وَإِنَّ اللَّهَ أَنْقَذَكُمْ بِالإِسْلاَمِ وَبِمُحَمَّدٍ صلى الله عليه وسلم حَتَّى بَلَغَ بِكُمْ مَا تَرَوْنَ، وَهَذِهِ الدُّنْيَا الَّتِي أَفْسَدَتْ بَيْنَكُمْ، إِنَّ ذَاكَ الَّذِي بِالشَّأْمِ وَاللَّهِ إِنْ يُقَاتِلُ إِلاَّ عَلَى الدُّنْيَا‏.‏\hadithno{7112}\hadithtrans{Narrated Abu Al-Minhal:When Ibn Ziyad and Marwan were in Sham and Ibn Az-Zubair took over the authority in Mecca and Qurra' (the Kharijites) revolted in Basra, I went out with my father to Abu Barza Al-Aslami till we entered upon him in his house while he was sitting in the shade of a room built of cane. So we sat with him and my father started talking to him saying, "O Abu Barza! Don't you see in what dilemma the people has fallen?" The first thing heard him saying "I seek reward from Allah for myself because of being angry and scornful at the Quraish tribe. O you Arabs! You know very well that you were in misery and were few in number and misguided, and that Allah has brought you out of all that with Islam and with Muhammad till He brought you to this state (of prosperity and happiness) which you see now; and it is this worldly wealth and pleasures which has caused mischief to appear among you. The one who is in Sham (i.e., Marwan), by Allah, is not fighting except for the sake of worldly gain: and those who are among you, by Allah, are not fighting except for the sake of worldly gain; and that one who is in Mecca (i.e., Ibn Az-Zubair) by Allah, is not fighting except for the sake of worldly gain}}
\hadithdefcmd{bukhari}{7113}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، عَنْ وَاصِلٍ الأَحْدَبِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ إِنَّ الْمُنَافِقِينَ الْيَوْمَ شَرٌّ مِنْهُمْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَانُوا يَوْمَئِذٍ يُسِرُّونَ وَالْيَوْمَ يَجْهَرُونَ‏.‏\hadithno{7113}\hadithtrans{Narrated Abi Waih:Hudhaifa bin Al-Yaman said, 'The hypocrites of today are worse than those of the lifetime of the Prophet, because in those days they used to do evil deeds secretly but today they do such deeds openly}}
\hadithdefcmd{bukhari}{7114}{حَدَّثَنَا خَلاَّدٌ، حَدَّثَنَا مِسْعَرٌ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنْ حُذَيْفَةَ، قَالَ إِنَّمَا كَانَ النِّفَاقُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَأَمَّا الْيَوْمَ فَإِنَّمَا هُوَ الْكُفْرُ بَعْدَ الإِيمَانِ‏.‏\hadithno{7114}\hadithtrans{Narrated Abi Asha'sha:Hudhaifa said, 'In fact, it was hypocrisy that existed in the lifetime of the Prophet (ﷺ) but today it is Kufr (disbelief) after belief}}
\hadithdefcmd{bukhari}{7115}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَمُرَّ الرَّجُلُ بِقَبْرِ الرَّجُلِ فَيَقُولُ يَا لَيْتَنِي مَكَانَهُ ‏"‏‏.‏\hadithno{7115}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till a man passes by a grave of somebody and says, 'Would that I were in his place}}
\hadithdefcmd{bukhari}{7116}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ أَخْبَرَنِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَضْطَرِبَ أَلَيَاتُ نِسَاءِ دَوْسٍ عَلَى ذِي الْخَلَصَةِ ‏"‏‏.‏ وَذُو الْخَلَصَةَ طَاغِيَةُ دَوْسٍ الَّتِي كَانُوا يَعْبُدُونَ فِي الْجَاهِلِيَّةِ‏.‏\hadithno{7116}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established till the buttocks of the women of the tribe of Daus move while going round Dhi-al-Khalasa." Dhi-al-Khalasa was the idol of the Daus tribe which they used to worship in the Pre Islamic Period of ignorance}}
\hadithdefcmd{bukhari}{7117}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي سُلَيْمَانُ، عَنْ ثَوْرٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَخْرُجَ رَجُلٌ مِنْ قَحْطَانَ يَسُوقُ النَّاسَ بِعَصَاهُ ‏"‏‏.‏\hadithno{7117}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established till a man from Qahtan appears, driving the people with his stick}}
\hadithdefcmd{bukhari}{7118}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ أَخْبَرَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَخْرُجَ نَارٌ مِنْ أَرْضِ الْحِجَازِ، تُضِيءُ أَعْنَاقَ الإِبِلِ بِبُصْرَى ‏"‏‏.‏\hadithno{7118}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established till a fire will come out of the land of Hijaz, and it will throw light on the necks of the camels at Busra}}
\hadithdefcmd{bukhari}{7119}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَدِّهِ، حَفْصِ بْنِ عَاصِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُوشِكُ الْفُرَاتُ أَنْ يَحْسِرَ عَنْ كَنْزٍ مِنْ ذَهَبٍ، فَمَنْ حَضَرَهُ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏‏.‏ قَالَ عُقْبَةُ وَحَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ يَحْسِرُ عَنْ جَبَلٍ مِنْ ذَهَبٍ ‏"‏‏.‏\hadithno{7119}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Soon the river "Euphrates" will disclose the treasure (the mountain) of gold, so whoever will be present at that time should not take anything of it." Al-A'raj narrated from Abu Huraira that the Prophet (ﷺ) said the same but he said, "It (Euphrates) will uncover a mountain of gold (under it)}}
\hadithdefcmd{bukhari}{7120}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنَا مَعْبَدٌ، سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَصَدَّقُوا، فَسَيَأْتِي عَلَى النَّاسِ زَمَانٌ يَمْشِي الرَّجُلُ بِصَدَقَتِهِ، فَلاَ يَجِدُ مَنْ يَقْبَلُهَا ‏"‏‏.‏ قَالَ مُسَدَّدٌ حَارِثَةُ أَخُو عُبَيْدِ اللَّهِ بْنِ عُمَرَ لأُمِّهِ‏ قَالَهُ أَبُو عَبْدِ اللَّهِ\hadithno{7120}\hadithtrans{Narrated Haritha bin Wahb:I heard Allah's Messenger (ﷺ) saying, "Give in charity because there will come a time on the people when a person will go out with his alms from place to place but will not find anybody to accept it}}
\hadithdefcmd{bukhari}{7121}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَقْتَتِلَ فِئَتَانِ عَظِيمَتَانِ، يَكُونُ بَيْنَهُمَا مَقْتَلَةٌ عَظِيمَةٌ، دَعْوَتُهُمَا وَاحِدَةٌ، وَحَتَّى يُبْعَثَ دَجَّالُونَ كَذَّابُونَ، قَرِيبٌ مِنْ ثَلاَثِينَ، كُلُّهُمْ يَزْعُمُ أَنَّهُ رَسُولُ اللَّهِ، وَحَتَّى يُقْبَضَ الْعِلْمُ، وَتَكْثُرَ الزَّلاَزِلُ، وَيَتَقَارَبَ الزَّمَانُ، وَتَظْهَرَ الْفِتَنُ، وَيَكْثُرَ الْهَرْجُ وَهْوَ الْقَتْلُ، وَحَتَّى يَكْثُرَ فِيكُمُ الْمَالُ فَيَفِيضَ، حَتَّى يُهِمَّ رَبَّ الْمَالِ مَنْ يَقْبَلُ صَدَقَتَهُ، وَحَتَّى يَعْرِضَهُ فَيَقُولَ الَّذِي يَعْرِضُهُ عَلَيْهِ لاَ أَرَبَ لِي بِهِ‏.‏ وَحَتَّى يَتَطَاوَلَ النَّاسُ فِي الْبُنْيَانِ، وَحَتَّى يَمُرَّ الرَّجُلُ بِقَبْرِ الرَّجُلِ فَيَقُولُ يَا لَيْتَنِي مَكَانَهُ‏.‏ وَحَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا، فَإِذَا طَلَعَتْ وَرَآهَا النَّاسُ ـ يَعْنِي ـ آمَنُوا أَجْمَعُونَ، فَذَلِكَ حِينَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ، أَوْ كَسَبَتْ فِي إِيمَانِهَا خَيْرًا، وَلَتَقُومَنَّ السَّاعَةُ وَقَدْ نَشَرَ الرَّجُلاَنِ ثَوْبَهُمَا بَيْنَهُمَا، فَلاَ يَتَبَايَعَانِهِ وَلاَ يَطْوِيَانِهِ، وَلَتَقُومَنَّ السَّاعَةُ وَقَدِ انْصَرَفَ الرَّجُلُ بِلَبَنِ لِقْحَتِهِ فَلاَ يَطْعَمُهُ، وَلَتَقُومَنَّ السَّاعَةُ وَهْوَ يُلِيطُ حَوْضَهُ فَلاَ يَسْقِي فِيهِ، وَلَتَقُومَنَّ السَّاعَةُ وَقَدْ رَفَعَ أُكْلَتَهُ إِلَى فِيهِ فَلاَ يَطْعَمُهَا ‏"‏‏.‏\hadithno{7121}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established (1) till two big groups fight each other whereupon there will be a great number of casualties on both sides and they will be following one and the same religious doctrine, (2) till about thirty Dajjals (liars) appear, and each one of them will claim that he is Allah's Messenger (ﷺ), (3) till the religious knowledge is taken away (by the death of Religious scholars) (4) earthquakes will increase in number (5) time will pass quickly, (6) afflictions will appear, (7) Al-Harj, (i.e., killing) will increase, (8) till wealth will be in abundance ---- so abundant that a wealthy person will worry lest nobody should accept his Zakat, and whenever he will present it to someone, that person (to whom it will be offered) will say, 'I am not in need of it, (9) till the people compete with one another in constructing high buildings, (10) till a man when passing by a grave of someone will say, 'Would that I were in his place (11) and till the sun rises from the West. So when the sun will rise and the people will see it (rising from the West) they will all believe (embrace Islam) but that will be the time when: (As Allah said,) 'No good will it do to a soul to believe then, if it believed not before, nor earned good (by deeds of righteousness) through its Faith.' (6.158) And the Hour will be established while two men spreading a garment in front of them but they will not be able to sell it, nor fold it up; and the Hour will be established when a man has milked his she-camel and has taken away the milk but he will not be able to drink it; and the Hour will be established before a man repairing a tank (for his livestock) is able to water (his animals) in it; and the Hour will be established when a person has raised a morsel (of food) to his mouth but will not be able to eat it}}
\hadithdefcmd{bukhari}{7122}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي قَيْسٌ، قَالَ قَالَ لِي الْمُغِيرَةُ بْنُ شُعْبَةَ مَا سَأَلَ أَحَدٌ النَّبِيَّ صلى الله عليه وسلم عَنِ الدَّجَّالِ مَا سَأَلْتُهُ وَإِنَّهُ قَالَ لِي ‏"‏ مَا يَضُرُّكَ مِنْهُ ‏"‏‏.‏ قُلْتُ لأَنَّهُمْ يَقُولُونَ إِنَّ مَعَهُ جَبَلَ خُبْزٍ وَنَهَرَ مَاءٍ‏.‏ قَالَ ‏"‏ هُوَ أَهْوَنُ عَلَى اللَّهِ مِنْ ذَلِكَ ‏"‏‏.‏\hadithno{7122}\hadithtrans{Narrated Al-Mughira bin Shu`ba:Nobody asked the Prophet (ﷺ) as many questions as I asked regarding Ad-Dajjal. The Prophet (ﷺ) said to me, "What worries you about him?" I said, "Because the people say that he will have a mountain of bread and a river of water with him (i.e. he will have abundance of food and water)" The Prophet (ﷺ) said, "Nay, he is too mean to be allowed such a thing by Allah"' (but it is only to test mankind whether they believe in Allah or in Ad-Dajjal)}}
\hadithdefcmd{bukhari}{7123}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أُرَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَعْوَرُ عَيْنِ الْيُمْنَى، كَأَنَّهَا عِنَبَةٌ طَافِيَةٌ ‏"‏‏.‏\hadithno{7123}\hadithtrans{Narrated Ibn 'Umar (ra) :The Prophet (ﷺ) said (about Ad-Dajjal) that he is one eyed, his right eye is as if a protruding out grape}}
\hadithdefcmd{bukhari}{7124}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَجِيءُ الدَّجَّالُ حَتَّى يَنْزِلَ فِي نَاحِيَةِ الْمَدِينَةِ، ثُمَّ تَرْجُفُ الْمَدِينَةُ ثَلاَثَ رَجَفَاتٍ، فَيَخْرُجُ إِلَيْهِ كُلُّ كَافِرٍ وَمُنَافِقٍ ‏"‏‏.‏\hadithno{7124}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Ad-Dajjal will come and encamp at a place close to Medina and then Medina will shake thrice whereupon every Kafir (disbeliever) and hypocrite will go out (of Medina) towards him}}
\hadithdefcmd{bukhari}{7125}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْمَدِينَةَ رُعْبُ الْمَسِيحِ الدَّجَّالِ، وَلَهَا يَوْمَئِذٍ سَبْعَةُ أَبْوَابٍ، عَلَى كُلِّ باب مَلَكَانِ ‏"‏‏.‏\hadithno{7125}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "The terror caused by Al-Masih Ad-Dajjal will not enter Medina and at that time Medina will have seven gates and there will be two angels at each gate (guarding them)}}
\hadithdefcmd{bukhari}{7126}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا سَعْدُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْمَدِينَةَ رُعْبُ الْمَسِيحِ، لَهَا يَوْمَئِذٍ سَبْعَةُ أَبْوَابٍ، عَلَى كُلِّ باب مَلَكَانِ ‏"‏‏.‏ قَالَ وَقَالَ ابْنُ إِسْحَاقَ عَنْ صَالِحِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، قَالَ قَدِمْتُ الْبَصْرَةَ فَقَالَ لِي أَبُو بَكْرَةَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{7126}\hadithtrans{Narrated Abu Bakra:[as above]}}
\hadithdefcmd{bukhari}{7127}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏ "‏ إِنِّي لأُنْذِرُكُمُوهُ، وَمَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَهُ قَوْمَهُ، وَلَكِنِّي سَأَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ، إِنَّهُ أَعْوَرُ وَإِنَّ اللَّهَ لَيْسَ بِأَعْوَرَ ‏"‏‏.‏\hadithno{7127}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) stood up amongst the people and then praised and glorified Allah as He deserved and then he mentioned Ad-Dajjal, saying, "I warn you of him, and there was no prophet but warned his followers of him; but I will tell you something about him which no prophet has told his followers: Ad- Dajjal is one-eyed whereas Allah is not}}
\hadithdefcmd{bukhari}{7128}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ أَطُوفُ بِالْكَعْبَةِ، فَإِذَا رَجُلٌ آدَمُ سَبْطُ الشَّعَرِ يَنْطُفُ ـ أَوْ يُهَرَاقُ ـ رَأْسُهُ مَاءً قُلْتُ مَنْ هَذَا قَالُوا ابْنُ مَرْيَمَ‏.‏ ثُمَّ ذَهَبْتُ أَلْتَفِتُ، فَإِذَا رَجُلٌ جَسِيمٌ أَحْمَرُ جَعْدُ الرَّأْسِ أَعْوَرُ الْعَيْنِ، كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِيَةٌ قَالُوا هَذَا الدَّجَّالُ‏.‏ أَقْرَبُ النَّاسِ بِهِ شَبَهًا ابْنُ قَطَنٍ ‏"‏‏.‏ رَجُلٌ مِنْ خُزَاعَةَ‏.‏\hadithno{7128}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said. "While I was sleeping, I saw myself (in a dream) performing Tawaf around the Ka`ba. Behold, I saw a reddish-white man with lank hair, and water was dropping from his head. I asked, "Who is this?' They replied, 'The son of Mary.' Then I turned my face to see another man with a huge body, red complexion and curly hair and blind in one eye. His eye looked like a protruding out grape. They said (to me), He is Ad-Dajjal." The Prophet (ﷺ) added, "The man he resembled most is Ibn Qatan, a man from the tribe of Khuza`a}}
\hadithdefcmd{bukhari}{7129}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَعِيذُ فِي صَلاَتِهِ مِنْ فِتْنَةِ الدَّجَّالِ‏.‏\hadithno{7129}\hadithtrans{Narrated `Aisha:I heard Allah's Messenger (ﷺ) in his prayer, seeking refuge with Allah from the afflictions of Ad-Dajjal}}
\hadithdefcmd{bukhari}{7130}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي الدَّجَّالِ ‏ "‏ إِنَّ مَعَهُ مَاءً وَنَارًا، فَنَارُهُ مَاءٌ بَارِدٌ، وَمَاؤُهُ نَارٌ ‏"‏‏.‏ قَالَ أَبُو مَسْعُودٍ أَنَا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7130}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said about Ad-Dajjal that he would have water and fire with him: (what would seem to be) fire, would be cold water and (what would seem to be) water, would be fire}}
\hadithdefcmd{bukhari}{7131}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، رضى الله عنه قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا بُعِثَ نَبِيٌّ إِلاَّ أَنْذَرَ أُمَّتَهُ الأَعْوَرَ الْكَذَّابَ، أَلاَ إِنَّهُ أَعْوَرُ، وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ، وَإِنَّ بَيْنَ عَيْنَيْهِ مَكْتُوبٌ كَافِرٌ ‏"‏‏.‏ فِيهِ أَبُو هُرَيْرَةَ وَابْنُ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7131}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "No prophet was sent but that he warned his followers against the one-eyed liar (Ad-Dajjal). Beware! He is blind in one eye, and your Lord is not so, and there will be written between his (Ad-Dajjal's) eyes (the word) Kafir (i.e., disbeliever)." (This Hadith is also quoted by Abu Huraira and Ibn `Abbas)}}
\hadithdefcmd{bukhari}{7132}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا سَعِيدٍ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا حَدِيثًا طَوِيلاً عَنِ الدَّجَّالِ، فَكَانَ فِيمَا يُحَدِّثُنَا بِهِ أَنَّهُ قَالَ ‏ "‏ يَأْتِي الدَّجَّالُ وَهُوَ مُحَرَّمٌ عَلَيْهِ أَنْ يَدْخُلَ نِقَابَ الْمَدِينَةِ، فَيَنْزِلُ بَعْضَ السِّبَاخِ الَّتِي تَلِي الْمَدِينَةَ، فَيَخْرُجُ إِلَيْهِ يَوْمَئِذٍ رَجُلٌ وَهْوَ خَيْرُ النَّاسِ أَوْ مِنْ خِيَارِ النَّاسِ، فَيَقُولُ أَشْهَدُ أَنَّكَ الدَّجَّالُ الَّذِي حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَهُ، فَيَقُولُ الدَّجَّالُ أَرَأَيْتُمْ إِنْ قَتَلْتُ هَذَا ثُمَّ أَحْيَيْتُهُ، هَلْ تَشُكُّونَ فِي الأَمْرِ فَيَقُولُونَ لاَ‏.‏ فَيَقْتُلُهُ ثُمَّ يُحْيِيهِ فَيَقُولُ وَاللَّهِ مَا كُنْتُ فِيكَ أَشَدَّ بَصِيرَةً مِنِّي الْيَوْمَ‏.‏ فَيُرِيدُ الدَّجَّالُ أَنْ يَقْتُلَهُ فَلاَ يُسَلَّطُ عَلَيْهِ ‏"‏‏.‏\hadithno{7132}\hadithtrans{Narrated Abu Sa`id:One day Allah's Messenger (ﷺ) narrated to us a long narration about Ad-Dajjal and among the things he narrated to us, was: "Ad-Dajjal will come, and he will be forbidden to enter the mountain passes of Medina. He will encamp in one of the salt areas neighboring Medina and there will appear to him a man who will be the best or one of the best of the people. He will say 'I testify that you are Ad-Dajjal whose story Allah's Messenger (ﷺ) has told us.' Ad-Dajjal will say (to his audience), 'Look, if I kill this man and then give him life, will you have any doubt about my claim?' They will reply, 'No,' Then Ad- Dajjal will kill that man and then will make him alive. The man will say, 'By Allah, now I recognize you more than ever!' Ad-Dajjal will then try to kill him (again) but he will not be given the power to do so}}
\hadithdefcmd{bukhari}{7133}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَى أَنْقَابِ الْمَدِينَةِ مَلاَئِكَةٌ، لاَ يَدْخُلُهَا الطَّاعُونُ وَلاَ الدَّجَّالُ ‏"‏‏.‏\hadithno{7133}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There are angels at the mountain passes of Medina (so that) neither plague nor Ad-Dajjal can enter it}}
\hadithdefcmd{bukhari}{7134}{حَدَّثَنِي يَحْيَى بْنُ مُوسَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَدِينَةُ يَأْتِيهَا الدَّجَّالُ، فَيَجِدُ الْمَلاَئِكَةَ يَحْرُسُونَهَا، فَلاَ يَقْرَبُهَا الدَّجَّالُ ـ قَالَ ـ وَلاَ الطَّاعُونُ، إِنْ شَاءَ اللَّهُ ‏"‏‏.‏\hadithno{7134}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Ad-Dajjal will come to Medina and find the angels guarding it. So Allah willing, neither Ad-Dajjal, nor plague will be able to come near it}}
\hadithdefcmd{bukhari}{7135}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، حَدَّثَتْهُ عَنْ أُمِّ حَبِيبَةَ بِنْتِ أَبِي سُفْيَانَ، عَنْ زَيْنَبَ ابْنَةِ جَحْشٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا يَوْمًا فَزِعًا يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ، فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏‏.‏ وَحَلَّقَ بِإِصْبَعَيْهِ الإِبْهَامِ وَالَّتِي تَلِيهَا‏.‏ قَالَتْ زَيْنَبُ ابْنَةُ جَحْشٍ فَقُلْتُ يَا رَسُولَ اللَّهِ أَفَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ إِذَا كَثُرَ الْخُبْثُ ‏"‏‏.‏\hadithno{7135}\hadithtrans{Narrated Zainab bint Jahsh:That one day Allah's Messenger (ﷺ) entered upon her in a state of fear and said, "None has the right to be worshipped but Allah! Woe to the Arabs from the Great evil that has approached (them). Today a hole has been opened in the dam of Gog and Magog like this." The Prophet (ﷺ) made a circle with his index finger and thumb. Zainab bint Jahsh added: I said, "O Allah's Apostle! Shall we be destroyed though there will be righteous people among us?" The Prophet (ﷺ) said, "Yes, if the (number) of evil (persons) increased}}
\hadithdefcmd{bukhari}{7136}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُفْتَحُ الرَّدْمُ رَدْمُ يَأْجُوجَ وَمَأْجُوجَ مِثْلَ هَذِهِ ‏"‏‏.‏ وَعَقَدَ وُهَيْبٌ تِسْعِينَ‏.‏\hadithno{7136}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A hole has been opened in the dam of Gog and Magog." Wuhaib (the sub-narrator) made the number 90 (with his index finger and thumb)}}
